# -*- coding: utf8 -*-

from portailuser.models import Ecole
from django.utils.safestring import mark_safe
from django.urls import reverse, NoReverseMatch, get_callable
from django.conf import settings

from club.views import PAGES, TITRES
from portailuser.admin_menu import AdminMenu
from lib.access_auth import addr_inp

widgets = []
for (app, title) in settings.APP_WIDGETS:
    try:
        settings_url = reverse(f"{app}:widget_settings")
    except NoReverseMatch:
        settings_url = None
    widgets.append((title, get_callable(f"{app}.views.widget"), settings_url))


def get_widgets(request):
    data = ""
    static_url = settings.STATIC_URL
    if request.is_secure():
        static_url = static_url.replace("http:", "https:")

    for (title, view, settings_link) in widgets:

        result = view(request)
        if result is not None:
            color = None
            if isinstance(result, tuple):
                (result, color) = result

            link = (
                ' <a href="{}"><img src="{}assets/icons/settings.png" alt="Réglages" /></a>'.format(
                    settings_link, static_url
                )
                if settings_link
                else ""
            )

            if color:
                data += '<dl class="{}">\n'.format(color)
            else:
                data += "<dl>\n"

            data += '<dt class="titre">' + link + title + "</dt>\n" + result + "</dl>"
    return mark_safe(data)


def autre_ecoles(request):
    proto = "https" if request.is_secure() else "http"
    res = []

    if request.ecole != Ecole.inp:
        res.append({"lien": "{}://{}/".format(proto, settings.URLS_SITES[0]), "nom": "INP"})
    if request.ecole != Ecole.n7:
        res.append(
            {
                "lien": "{}://{}/".format(proto, settings.URLS_SITES[1]),
                "nom": "ENSEEIHT",
            }
        )
    if request.ecole != Ecole.ensat:
        res.append({"lien": "{}://{}/".format(proto, settings.URLS_SITES[2]), "nom": "ENSAT"})
    if request.ecole != Ecole.a7:
        res.append(
            {
                "lien": "{}://{}/".format(proto, settings.URLS_SITES[3]),
                "nom": "ENSIACET",
            }
        )
    if request.ecole != Ecole.enm:
        res.append({"lien": "{}://{}/".format(proto, settings.URLS_SITES[4]), "nom": "ENM"})

    return res


def menu_clubs(request):
    elements = ""
    for lien in PAGES:
        titre_p = PAGES[lien]  # lien vers le titre du sous-menu
        # solution gitanne pour gérer le cas de plusieurs éléments (pour "autres")
        if len(titre_p) == 1:
            titre_t = TITRES[titre_p[0]]
        else:
            titre_t = TITRES["autre"]

        elements += '<li><a href="/clubs/{}">{}</a></li>\n'.format(lien, titre_t)

    return mark_safe(elements)


def common_processors(request):
    return {
        "current_path": request.get_full_path(),
        "site_ecole": request.ecole,
        "autre_ecoles": autre_ecoles(request),
        "widgets": get_widgets(request) if not hasattr(request, "desactiver_widgets") else "",
        "menu_gestion": AdminMenu.get_instance().get_menu_for(request),
        "menu_clubs": menu_clubs(request),
        "MEDIA_URL": settings.MEDIA_URL.replace("http:", "https:") if request.is_secure() else settings.MEDIA_URL,
        "ADDR_INP": addr_inp(request.META["REMOTE_ADDR"]),
        "acces_frappe": request.user.is_authenticated and request.user.get_ldap_user().inscritFrappe,
    }
